#include "debug_out.h"

#include <sstream>

#include <mtxclient/http/errors.hpp>

QDebug operator<<(QDebug debug, const mtx::http::ClientError &error) {
    QDebugStateSaver saver(debug);

    auto s = [](const auto &a) {
        std::stringstream s;
        s << a;
        return QString::fromStdString(s.str());
    };

    if (!error.parse_error.empty())
        debug.nospace() << "JSON parse error: " << QString::fromStdString(error.parse_error);
    if (error.status_code != boost::beast::http::status::ok)
        debug.nospace() << "HTTP error: " << s(error.status_code);
    if (error.error_code)
        debug.nospace() << "Network error: " << s(error.error_code);
    if (!error.matrix_error.error.empty())
        debug.nospace() << "Matrix error " << QString::fromStdString(to_string(error.matrix_error.errcode)) << ": "
                        << s(error.matrix_error.error);

    return debug;
}
